==> activity-center-api-0.9.1.90-cwy-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/ResourceIdeaDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import java.io.Serializable;

/**
 * 创意
 *
 * @author weny.cai
 * @date 2018/12/3 14:27
 **/
public class ResourceIdeaDto implements Serializable {

    private Long id;

    private Long resourceId;

    private String ideaName;

    private Integer switchState;

    private Long slotId;

    private String ideaTitle;

    private String ideaDesc;

    private String buttonText;

    private String iconUrl;

    private String picUrl;

    private Integer directType;

    private Integer budgetType;

    private Double dayBudget;

    private Double ideaPrice;

    private Integer seqNum;

    private String resourceName;

    private String groupName;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getResourceId() {
        return resourceId;
    }

    public void setResourceId(Long resourceId) {
        this.resourceId = resourceId;
    }

    public String getIdeaName() {
        return ideaName;
    }

    public void setIdeaName(String ideaName) {
        this.ideaName = ideaName;
    }

    public Integer getSwitchState() {
        return switchState;
    }

    public void setSwitchState(Integer switchState) {
        this.switchState = switchState;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getIdeaTitle() {
        return ideaTitle;
    }

    public void setIdeaTitle(String ideaTitle) {
        this.ideaTitle = ideaTitle;
    }

    public String getIdeaDesc() {
        return ideaDesc;
    }

    public void setIdeaDesc(String ideaDesc) {
        this.ideaDesc = ideaDesc;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getIconUrl() {
        return iconUrl;
    }

    public void setIconUrl(String iconUrl) {
        this.iconUrl = iconUrl;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public Integer getDirectType() {
        return directType;
    }

    public void setDirectType(Integer directType) {
        this.directType = directType;
    }

    public Integer getBudgetType() {
        return budgetType;
    }

    public void setBudgetType(Integer budgetType) {
        this.budgetType = budgetType;
    }

    public Double getDayBudget() {
        return dayBudget;
    }

    public void setDayBudget(Double dayBudget) {
        this.dayBudget = dayBudget;
    }

    public Double getIdeaPrice() {
        return ideaPrice;
    }

    public void setIdeaPrice(Double ideaPrice) {
        this.ideaPrice = ideaPrice;
    }

    public Integer getSeqNum() {
        return seqNum;
    }

    public void setSeqNum(Integer seqNum) {
        this.seqNum = seqNum;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }
}

==> activity-center-api-0.9.1.94-cwy-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/ResourceIdeaDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import java.io.Serializable;

/**
 * 创意
 *
 * @author weny.cai
 * @date 2018/12/3 14:27
 **/
public class ResourceIdeaDto implements Serializable {

    private Long id;

    private Long resourceId;

    private String ideaName;

    private Integer switchState;

    private Long slotId;

    private String ideaTitle;

    private String ideaDesc;

    private String buttonText;

    private String iconUrl;

    private String picUrl;

    private Integer directType;

    private Integer budgetType;

    private Double dayBudget;

    private Double ideaPrice;

    private Integer seqNum;

    private String resourceName;

    private String groupName;

    private ResourceLocationDto resourceLocationDto;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getResourceId() {
        return resourceId;
    }

    public void setResourceId(Long resourceId) {
        this.resourceId = resourceId;
    }

    public String getIdeaName() {
        return ideaName;
    }

    public void setIdeaName(String ideaName) {
        this.ideaName = ideaName;
    }

    public Integer getSwitchState() {
        return switchState;
    }

    public void setSwitchState(Integer switchState) {
        this.switchState = switchState;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getIdeaTitle() {
        return ideaTitle;
    }

    public void setIdeaTitle(String ideaTitle) {
        this.ideaTitle = ideaTitle;
    }

    public String getIdeaDesc() {
        return ideaDesc;
    }

    public void setIdeaDesc(String ideaDesc) {
        this.ideaDesc = ideaDesc;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getIconUrl() {
        return iconUrl;
    }

    public void setIconUrl(String iconUrl) {
        this.iconUrl = iconUrl;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public Integer getDirectType() {
        return directType;
    }

    public void setDirectType(Integer directType) {
        this.directType = directType;
    }

    public Integer getBudgetType() {
        return budgetType;
    }

    public void setBudgetType(Integer budgetType) {
        this.budgetType = budgetType;
    }

    public Double getDayBudget() {
        return dayBudget;
    }

    public void setDayBudget(Double dayBudget) {
        this.dayBudget = dayBudget;
    }

    public Double getIdeaPrice() {
        return ideaPrice;
    }

    public void setIdeaPrice(Double ideaPrice) {
        this.ideaPrice = ideaPrice;
    }

    public Integer getSeqNum() {
        return seqNum;
    }

    public void setSeqNum(Integer seqNum) {
        this.seqNum = seqNum;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public ResourceLocationDto getResourceLocationDto() {
        return resourceLocationDto;
    }

    public void setResourceLocationDto(ResourceLocationDto resourceLocationDto) {
        this.resourceLocationDto = resourceLocationDto;
    }
}
